@@ -6,7 +6,7 @@ use Carp;
 use Class::MakeMethods '-isasubclass';
 
 use vars qw( $VERSION );
-$VERSION = 1.005;
+$VERSION = 1.008;
 
 sub _diagnostic { &Class::MakeMethods::_diagnostic }
 
@@ -275,8 +275,23 @@ _behavior_builder( $mm_def, $behavior, $m_info );
     
     # If the MM def provides a "-subs" call, for forwarding and other
     # miscelaneous "subsidiary" or "contained" methods, run it.
-    if ( local $_ = $mm_def->{'behavior'}->{'-subs'} ) {
-      push @methods, map $_->( $m_info ), (ref($_) eq 'ARRAY') ? @$_ : $_;
+    if ( my $subs = $mm_def->{'behavior'}->{'-subs'} ) {
+      my @subs = (ref($subs) eq 'ARRAY') ? @$subs : $subs;
+      foreach my $sub ( @subs ) {
+	my @results = $sub->($m_info);
+	if ( scalar @results == 1 and ref($results[0]) eq 'HASH' ) {
+	  # If it returns a hash of helper method types, check the method info
+	  # for any matching names and call the corresponding method generator.
+	  my $types = shift @results;
+	  foreach my $type ( keys %$types ) {
+	    my $names = $m_info->{$type} or next; 
+	    my @names = ref($names) eq 'ARRAY' ? @$names : split(' ', $names);
+	    my $generator = $types->{$type};
+	    push @results, map { $_ => &$generator($m_info, $_) } @names;
+	  }	
+	}
+	push @methods, @results;
+      }
     }
     
     # If the MM def provides a "-register" call, for registering meta-method
@@ -510,7 +525,7 @@ individual scalar values.
 
 Thse definitions are then re-used and modified by various B<template
 subclasses>. For example, the C<Template::Hash> subclass supports
-blessed-hash objects, while the C<Template::Static> subclass supports
+blessed-hash objects, while the C<Template::Global> subclass supports
 shared data; each of them includes an appropriate version of the
 C<scalar> accessor template for those object types.
 
@@ -997,7 +1012,7 @@ Example: The below defines methods e_get, e_set, and e_clear.
 If the provided name does not contain an asterisk, it will not be
 modified for individual meta-methods; for examples, see the bit_fields
 method generated by Generic bits, and the DESTROY method generated
-by Flyweight meta-methods.
+by InsideOut meta-methods.
 
 In addition to the name-to-behavior correspondences described above,
 interfaces may also contain additional entries with keys begining
